@@ -96,17 +96,19 @@
 #' @param ncol Number of plots to display per column for each effect.
 #'   If \code{NULL} (default), \code{ncol} is computed internally based
 #'   on the number of rows of \code{conditions}.
-#' @param points Logical. Indicates if the original data points
-#'   should be added via \code{\link{geom_jitter}}.
-#'   Default is \code{FALSE}. Note that only those data points will be added
-#'   that match the specified conditions defined in \code{conditions}.
-#'   For categorical predictors, the conditions have to match exactly.
-#'   For numeric predictors, argument \code{select_points} is used to
-#'   determine, which points do match a condition.
-#' @param rug Logical. Indicates if a rug representation of predictor
-#'   values should be added via \code{\link{geom_rug}}.
-#'   Default is \code{FALSE}. Depends on \code{select_points} in the same
-#'   way as \code{points} does.
+#' @param points Logical. Indicates if the original data points should be added
+#'   via \code{\link[ggplot2:geom_jitter]{geom_jitter}}. Default is
+#'   \code{FALSE}. Can be controlled globally via the \code{brms.plot_points}
+#'   option. Note that only those data points will be added that match the
+#'   specified conditions defined in \code{conditions}. For categorical
+#'   predictors, the conditions have to match exactly. For numeric predictors,
+#'   argument \code{select_points} is used to determine, which points do match a
+#'   condition.
+#' @param rug Logical. Indicates if a rug representation of predictor values
+#'   should be added via \code{\link[ggplot2:geom_rug]{geom_rug}}. Default is
+#'   \code{FALSE}. Depends on \code{select_points} in the same way as
+#'   \code{points} does. Can be controlled globally via the \code{brms.plot_rug}
+#'   option.
 #' @param mean Logical. Only relevant for spaghetti plots.
 #'   If \code{TRUE} (the default), display the mean regression
 #'   line on top of the regression lines for each sample.
@@ -118,30 +120,30 @@
 #'   Either \code{"contour"} or \code{"raster"}.
 #' @param line_args Only used in plots of continuous predictors:
 #'   A named list of arguments passed to
-#'   \code{\link{geom_smooth}}.
+#'   \code{\link[ggplot2:geom_smooth]{geom_smooth}}.
 #' @param cat_args Only used in plots of categorical predictors:
 #'   A named list of arguments passed to
-#'   \code{\link{geom_point}}.
+#'   \code{\link[ggplot2:geom_point]{geom_point}}.
 #' @param errorbar_args Only used in plots of categorical predictors:
 #'   A named list of arguments passed to
-#'   \code{\link{geom_errorbar}}.
+#'   \code{\link[ggplot2:geom_errorbar]{geom_errorbar}}.
 #' @param surface_args Only used in surface plots:
 #'   A named list of arguments passed to
-#'   \code{\link{geom_contour}} or
-#'   \code{\link{geom_raster}}
+#'   \code{\link[ggplot2:geom_contour]{geom_contour}} or
+#'   \code{\link[ggplot2:geom_raster]{geom_raster}}
 #'   (depending on argument \code{stype}).
 #' @param spaghetti_args Only used in spaghetti plots:
 #'   A named list of arguments passed to
-#'   \code{\link{geom_smooth}}.
+#'   \code{\link[ggplot2:geom_smooth]{geom_smooth}}.
 #' @param point_args Only used if \code{points = TRUE}:
 #'   A named list of arguments passed to
-#'   \code{\link{geom_jitter}}.
+#'   \code{\link[ggplot2:geom_jitter]{geom_jitter}}.
 #' @param rug_args Only used if \code{rug = TRUE}:
 #'   A named list of arguments passed to
-#'   \code{\link{geom_rug}}.
-#' @param facet_args Only used if if multiple condtions are provided:
+#'   \code{\link[ggplot2:geom_rug]{geom_rug}}.
+#' @param facet_args Only used if if multiple conditions are provided:
 #'   A named list of arguments passed to
-#'   \code{\link{facet_wrap}}.
+#'   \code{\link[ggplot2:facet_wrap]{facet_wrap}}.
 #'
 #' @return An object of class \code{'brms_conditional_effects'} which is a
 #'   named list with one data.frame per effect containing all information
@@ -154,7 +156,7 @@
 #'   rows).
 #'
 #'   The corresponding \code{plot} method returns a named
-#'   list of \code{\link{ggplot}} objects, which can be further
+#'   list of \code{\link[ggplot2:ggplot]{ggplot}} objects, which can be further
 #'   customized using the \pkg{ggplot2} package.
 #'
 #' @details When creating \code{conditional_effects} for a particular predictor
@@ -170,7 +172,8 @@
 #'
 #'   To fully change colors of the created plots, one has to amend both
 #'   \code{scale_colour} and \code{scale_fill}. See
-#'   \code{\link{scale_colour_grey}} or \code{\link{scale_colour_gradient}} for
+#'   \code{\link[ggplot2:scale_color_grey]{scale_colour_grey}} or
+#'   \code{\link[ggplot2:scale_color_gradient]{scale_colour_gradient}} for
 #'   more details.
 #'
 #' @examples
@@ -183,8 +186,8 @@
 #'
 #' ## change colours to grey scale
 #' library(ggplot2)
-#' me <- conditional_effects(fit, "zBase:Trt")
-#' plot(me, plot = FALSE)[[1]] +
+#' ce <- conditional_effects(fit, "zBase:Trt")
+#' plot(ce, plot = FALSE)[[1]] +
 #'   scale_color_grey() +
 #'   scale_fill_grey()
 #'
@@ -214,11 +217,11 @@
 #' conditions <- make_conditions(fit3way, "zAge")
 #' conditional_effects(fit3way, "zBase:Trt", conditions = conditions)
 #' ## only include points close to the specified values of zAge
-#' me <- conditional_effects(
+#' ce <- conditional_effects(
 #'   fit3way, "zBase:Trt", conditions = conditions,
 #'   select_points = 0.1
 #' )
-#' plot(me, points = TRUE)
+#' plot(ce, points = TRUE)
 #' }
 #'
 #' @export
@@ -518,8 +521,8 @@ get_all_effects.mvbrmsterms <- function(x, ...) {
 # @return a list with one element per valid effect / effects combination
 #   excludes all 3-way or higher interactions
 #' @export
-get_all_effects.brmsterms <- function(x, rsv_vars = NULL, comb_all = FALSE) {
-  stopifnot(is.atomic(rsv_vars))
+get_all_effects.brmsterms <- function(x, rsv_vars = NULL, comb_all = FALSE, ...) {
+  stopifnot(is_atomic_or_null(rsv_vars))
   out <- list()
   for (dp in names(x$dpars)) {
     out <- c(out, get_all_effects(x$dpars[[dp]]))
@@ -564,14 +567,14 @@ get_all_effects_type <- function(x, type) {
     term_parts <- unlist(strsplit(terms[i], split = ":"))
     vars <- vector("list", length(term_parts))
     for (j in seq_along(term_parts)) {
-      if (grepl_expr(regex_type, term_parts[j])) {
-        # evaluate a special term to extract variables
-        tmp <- eval2(term_parts[j])
-        vars[[j]] <- setdiff(unique(c(tmp$term, tmp$by)), "NA")
-      } else {
-        # extract all variables from an ordinary term
-        vars[[j]] <- all_vars(term_parts[j])
+      matches <- get_matches_expr(regex_type, term_parts[j])
+      for (k in seq_along(matches)) {
+        # evaluate special terms to extract variables
+        tmp <- eval2(matches[[k]])
+        c(vars[[j]]) <- setdiff(unique(c(tmp$term, tmp$by)), "NA")
       }
+      # extract all variables not part of any special term
+      c(vars[[j]]) <- setdiff(all_vars(term_parts[j]), all_vars(matches))
     }
     vars <- unique(unlist(vars))
     out[[i]] <- str2formula(vars, collapse = "*")
@@ -606,7 +609,8 @@ get_int_vars.mvbrmsterms <- function(x, ...) {
 
 #' @export
 get_int_vars.brmsterms <- function(x, ...) {
-  advars <- ulapply(rmNULL(x$adforms[c("trials", "thres", "vint")]), all_vars)
+  adterms <- c("trials", "thres", "vint")
+  advars <- ulapply(rmNULL(x$adforms[adterms]), all_vars)
   unique(c(advars, get_sp_vars(x, "mo")))
 }
 
@@ -899,7 +903,7 @@ prepare_cond_data <- function(data, conditions, int_conditions = NULL,
   }
   # no need to have the same value combination more than once
   data <- unique(data)
-  data <- data[do_call(order, as.list(data)), , drop = FALSE]
+  data <- data[do_call(order, unname(as.list(data))), , drop = FALSE]
   data <- replicate(nrow(conditions), data, simplify = FALSE)
   cond_vars <- setdiff(names(conditions), effects)
   cond__ <- get_cond__(conditions)
@@ -930,7 +934,7 @@ make_point_frame <- function(bterms, mf, effects, conditions,
     model.frame(bterms$respform, mf, na.action = na.pass)
   )
   req_vars <- names(mf)
-  groups <- get_re_groups(bterms)
+  groups <- get_re_group_vars(bterms)
   if (length(groups)) {
     c(req_vars) <- unlist(strsplit(groups, ":"))
   }
@@ -1017,9 +1021,11 @@ print.brms_conditional_effects <- function(x, ...) {
 
 #' @rdname conditional_effects.brmsfit
 #' @method plot brms_conditional_effects
+#' @importFrom rlang .data
 #' @export
 plot.brms_conditional_effects <- function(
-  x, ncol = NULL, points = FALSE, rug = FALSE, mean = TRUE,
+  x, ncol = NULL, points = getOption("brms.plot_points", FALSE),
+  rug = getOption("brms.plot_rug", FALSE), mean = TRUE,
   jitter_width = 0, stype = c("contour", "raster"),
   line_args = list(), cat_args = list(), errorbar_args = list(),
   surface_args = list(), spaghetti_args = list(), point_args = list(),
@@ -1061,12 +1067,12 @@ plot.brms_conditional_effects <- function(
     if (surface || ordinal) {
       # surface plots for two dimensional interactions or ordinal plots
       plots[[i]] <- ggplot(x[[i]]) +
-        aes_(~ effect1__, ~ effect2__) +
+        aes(.data[["effect1__"]], .data[["effect2__"]]) +
         labs(x = effects[1], y = effects[2])
       if (ordinal) {
         width <- ifelse(is_like_factor(x[[i]]$effect1__), 0.9, 1)
         .surface_args <- nlist(
-          mapping = aes_(fill = ~ estimate__),
+          mapping = aes(fill = .data[["estimate__"]]),
           height = 0.9, width = width
         )
         replace_args(.surface_args, dont_replace) <- surface_args
@@ -1076,15 +1082,18 @@ plot.brms_conditional_effects <- function(
           ylab(response)
       } else if (stype == "contour") {
         .surface_args <- nlist(
-          mapping = aes_(z = ~ estimate__, colour = ~ ..level..),
-          bins = 30, size = 1.3
+          mapping = aes(
+            z = .data[["estimate__"]],
+            colour = after_stat(.data[["level"]])
+          ),
+          bins = 30, linewidth = 1.3
         )
         replace_args(.surface_args, dont_replace) <- surface_args
         plots[[i]] <- plots[[i]] +
           do_call(geom_contour, .surface_args) +
           scale_color_gradientn(colors = viridis6(), name = response)
       } else if (stype == "raster") {
-        .surface_args <- nlist(mapping = aes_(fill = ~ estimate__))
+        .surface_args <- nlist(mapping = aes(fill = .data[["estimate__"]]))
         replace_args(.surface_args, dont_replace) <- surface_args
         plots[[i]] <- plots[[i]] +
           do_call(geom_raster, .surface_args) +
@@ -1094,12 +1103,18 @@ plot.brms_conditional_effects <- function(
       # plot effects of single predictors or two-way interactions
       gvar <- if (length(effects) == 2L) "effect2__"
       spaghetti <- attr(x[[i]], "spaghetti")
-      plots[[i]] <- ggplot(x[[i]]) +
-        aes_string(x = "effect1__", y = "estimate__", colour = gvar) +
+      aes_tmp <- aes(x = .data[["effect1__"]], y = .data[["estimate__"]])
+      if (!is.null(gvar)) {
+        aes_tmp$colour <- aes(colour = .data[[gvar]])$colour
+      }
+      plots[[i]] <- ggplot(x[[i]]) + aes_tmp +
         labs(x = effects[1], y = response, colour = effects[2])
       if (is.null(spaghetti)) {
-        plots[[i]] <- plots[[i]] +
-          aes_string(ymin = "lower__", ymax = "upper__", fill = gvar) +
+        aes_tmp <- aes(ymin = .data[["lower__"]], ymax = .data[["upper__"]])
+        if (!is.null(gvar)) {
+          aes_tmp$fill <- aes(fill = .data[[gvar]])$fill
+        }
+        plots[[i]] <- plots[[i]] + aes_tmp +
           labs(fill = effects[2])
       }
       # extract suggested colors for later use
@@ -1108,13 +1123,13 @@ plot.brms_conditional_effects <- function(
       if (points && !categorical && !surface) {
         # add points first so that they appear behind the predictions
         .point_args <- list(
-          mapping = aes_string(x = "effect1__", y = "resp__"),
+          mapping = aes(x = .data[["effect1__"]], y = .data[["resp__"]]),
           data = df_points, inherit.aes = FALSE,
           size = 2 / ncond^0.25, height = 0, width = jitter_width
         )
         if (is_like_factor(df_points[, gvar])) {
           .point_args$mapping[c("colour", "fill")] <-
-            aes_string(colour = gvar, fill = gvar)
+            aes(colour = .data[[gvar]], fill = .data[[gvar]])
         }
         replace_args(.point_args, dont_replace) <- point_args
         plots[[i]] <- plots[[i]] +
@@ -1123,9 +1138,12 @@ plot.brms_conditional_effects <- function(
       if (!is.null(spaghetti)) {
         # add a regression line for each sample separately
         .spaghetti_args <- list(
-          aes_string(group = "sample__", colour = gvar),
-          data = spaghetti, stat = "identity", size = 0.5
+          aes(group = .data[["sample__"]]),
+          data = spaghetti, stat = "identity", linewidth = 0.5
         )
+        if (!is.null(gvar)) {
+          .spaghetti_args[[1]]$colour <- aes(colour = .data[[gvar]])$colour
+        }
         if (length(effects) == 1L) {
           .spaghetti_args$colour <- alpha("blue", 0.1)
         } else {
@@ -1142,7 +1160,9 @@ plot.brms_conditional_effects <- function(
         .line_args <- list(stat = "identity")
         if (!is.null(spaghetti)) {
           # display a white mean regression line
-          .line_args$mapping <- aes_string(group = gvar)
+          if (!is.null(gvar)) {
+            .line_args$mapping <- aes(group = .data[[gvar]])
+          }
           .line_args$colour <- alpha("white", 0.8)
         }
         replace_args(.line_args, dont_replace) <- line_args
@@ -1152,12 +1172,11 @@ plot.brms_conditional_effects <- function(
         }
         if (rug) {
           .rug_args <- list(
-            aes_string(x = "effect1__"), sides = "b",
+            mapping = aes(x = .data[["effect1__"]]), sides = "b",
             data = df_points, inherit.aes = FALSE
           )
           if (is_like_factor(df_points[, gvar])) {
-            .point_args$mapping[c("colour", "fill")] <-
-              aes_string(colour = gvar, fill = gvar)
+            .rug_args$mapping["colour"] <- aes(colour = .data[[gvar]])
           }
           replace_args(.rug_args, dont_replace) <- rug_args
           plots[[i]] <- plots[[i]] +
