@@ -83,7 +83,7 @@ data_response.brmsframe <- function(x, data, check_response = TRUE,
   Y <- model.response(model.frame(x$respform, data, na.action = na.pass))
   out <- list(N = N, Y = unname(Y))
   if (is_binary(x$family)) {
-    bin_levels <- x$basis$resp_levels
+    bin_levels <- x$frame$basis$resp_levels
     if (is.null(bin_levels)) {
       bin_levels <- levels(as.factor(out$Y))
     }
@@ -100,7 +100,7 @@ data_response.brmsframe <- function(x, data, check_response = TRUE,
     out$Y <- as.integer(as_factor(out$Y, levels = bin_levels)) - 1
   }
   if (is_categorical(x$family)) {
-    out$Y <- as.integer(as_factor(out$Y, levels = x$basis$resp_levels))
+    out$Y <- as.integer(as_factor(out$Y, levels = x$frame$basis$resp_levels))
   }
   if (is_ordinal(x$family) && is.ordered(out$Y)) {
     diff <- ifelse(has_extra_cat(x$family), 1L, 0L)
