@@ -11,6 +11,7 @@
 #   normalized: suffixes of Stan lpdfs or lpmfs which only exist as normalized
 #     versions; can also be "" in which case the family is always normalized
 #   specials: character vector specialties of some families
+#     TODO: create an overview of all specials
 
 .family_gaussian <- function() {
   list(
@@ -60,6 +61,32 @@
   )
 }
 
+.family_xbeta <- function() {
+  list(
+    links = c(
+      "logit", "probit", "probit_approx", "cloglog",
+      "cauchit", "softit", "identity", "log"
+    ),
+    dpars = c("mu", "phi", "kappa"),
+    type = "real",
+    ybounds = c(0, 1),
+    closed = c(TRUE, TRUE),
+    ad = c("weights", "subset", "index"),
+    include = "fun_xbeta.stan",
+    prior = function(dpar, link = "identity", ...) {
+      if (dpar == "kappa") {
+        if (link == "identity") {
+          return("gamma(0.01, 0.01)")
+        } else {
+          return("student_t(3, 0, 2.5)")
+        }
+      }
+      NULL
+    },
+    normalized = ""
+  )
+}
+
 .family_beta_binomial <- function() {
   list(
     links = c(
@@ -111,6 +138,20 @@
   )
 }
 
+.family_dirichlet_multinomial <- function() {
+  list(
+    links = "logit",
+    dpars = "phi",
+    multi_dpars = "mu",  # size determined by the data
+    type = "int", ybounds = c(-Inf, Inf),
+    closed = c(NA, NA),
+    ad = c("weights", "subset", "trials", "index"),
+    specials = c("multinomial", "joint_link"),
+    include = "fun_dirichlet_multinomial_logit.stan",
+    normalized = ""
+  )
+}
+
 .family_beta <- function() {
   list(
     links = c(
@@ -181,7 +222,13 @@
     dpars = c("mu", "shape"), type = "int",
     ybounds = c(0, Inf), closed = c(TRUE, NA),
     ad = c("weights", "subset", "cens", "trunc", "rate", "index"),
-    specials = "sbi_log"
+    specials = "sbi_log",
+    prior = function(dpar, link = "identity", ...) {
+      if (dpar == "shape" && link == "identity") {
+        return("inv_gamma(0.4, 0.3)")
+      }
+      NULL
+    }
   )
 }
 
@@ -192,7 +239,13 @@
     dpars = c("mu", "sigma"), type = "int",
     ybounds = c(0, Inf), closed = c(TRUE, NA),
     ad = c("weights", "subset", "cens", "trunc", "rate", "index"),
-    specials = "sbi_log"
+    specials = "sbi_log",
+    prior = function(dpar, link = "identity", ...) {
+      if (dpar == "sigma" && link == "identity") {
+        return("gamma(0.4, 0.3)")
+      }
+      NULL
+    }
   )
 }
 
@@ -335,8 +388,14 @@
     dpars = c("mu", "kappa"), type = "real",
     ybounds = c(-pi, pi), closed = c(TRUE, TRUE),
     ad = c("weights", "subset", "cens", "trunc", "mi", "index"),
-    include = c("fun_tan_half.stan", "fun_von_mises.stan"),
-    normalized = ""
+    include = c("fun_tan_half.stan"),
+    normalized = "",
+    prior = function(dpar, link = "identity", ...) {
+      if (dpar == "mu" && link == "tan_half") {
+        return("student_t(1, 0, 1)")
+      }
+      NULL
+    }
   )
 }
 
@@ -366,7 +425,7 @@
     links = c("log", "identity", "softplus", "squareplus"),
     dpars = c("mu"), type = "real",
     ybounds = c(0, Inf), closed = c(TRUE, NA),
-    ad = c("weights", "subset", "cens", "trunc", "index"),
+    ad = c("weights", "subset", "cens", "trunc", "index", "bhaz"),
     include = "fun_cox.stan",
     specials = c("cox", "sbi_log", "sbi_log_cdf"),
     normalized = ""
@@ -452,7 +511,13 @@
     ad = c("weights", "subset", "cens", "trunc", "index"),
     include = "fun_hurdle_negbinomial.stan",
     specials = c("sbi_log", "sbi_hu_logit"),
-    normalized = ""
+    normalized = "",
+    prior = function(dpar, link = "identity", ...) {
+      if (dpar == "shape" && link == "identity") {
+        return("inv_gamma(0.4, 0.3)")
+      }
+      NULL
+    }
   )
 }
 
@@ -463,7 +528,7 @@
     ybounds = c(0, Inf), closed = c(TRUE, NA),
     ad = c("weights", "subset", "cens", "trunc", "index"),
     include = "fun_hurdle_gamma.stan",
-    specials = "sbi_hu_logit",
+    specials = c("sbi_hu_logit", "cont_hurdle"),
     normalized = ""
   )
 }
@@ -475,7 +540,7 @@
     ybounds = c(0, Inf), closed = c(TRUE, NA),
     ad = c("weights", "subset", "cens", "trunc", "index"),
     include = "fun_hurdle_lognormal.stan",
-    specials = c("logscale", "sbi_hu_logit"),
+    specials = c("logscale", "sbi_hu_logit", "cont_hurdle"),
     normalized = ""
   )
 }
@@ -517,7 +582,13 @@
     ad = c("weights", "subset", "cens", "trunc", "index"),
     include = "fun_zero_inflated_negbinomial.stan",
     specials = c("sbi_log", "sbi_zi_logit"),
-    normalized = ""
+    normalized = "",
+    prior = function(dpar, link = "identity", ...) {
+      if (dpar == "shape" && link == "identity") {
+        return("inv_gamma(0.4, 0.3)")
+      }
+      NULL
+    }
   )
 }
 
@@ -563,7 +634,7 @@
     ybounds = c(0, 1), closed = c(TRUE, FALSE),
     ad = c("weights", "subset", "cens", "trunc", "index"),
     include = "fun_zero_inflated_beta.stan",
-    specials = "sbi_zi_logit",
+    specials = c("sbi_zi_logit", "cont_hurdle"),
     normalized = ""
   )
 }
@@ -578,7 +649,7 @@
     ybounds = c(0, 1), closed = c(TRUE, TRUE),
     ad = c("weights", "subset", "index"),
     include = "fun_zero_one_inflated_beta.stan",
-    specials = "sbi_zi_logit",
+    specials = c("sbi_zi_logit", "cont_hurdle"),
     normalized = ""
   )
 }
