@@ -16,7 +16,7 @@
 #' @param cov Name of the covariance kernel. Currently supported are
 #'   \code{"exp_quad"} (exponentiated-quadratic kernel; default),
 #'   \code{"matern32"} (Matern 3/2 kernel), \code{"matern52"} (Matern 5/2 kernel),
-#'   and \code{"exponential"} (exponential kernel).
+#'   and \code{"exponential"} (exponential kernel; alias: \code{"matern12"}).
 #' @param iso A flag to indicate whether an isotropic (\code{TRUE}; the
 #'   default) or a non-isotropic GP should be used.
 #'   In the former case, the same amount of smoothing is applied to all
@@ -64,6 +64,30 @@
 #'  \url{https://mc-stan.org/docs/functions-reference/matrix_operations.html}
 #'  under "Gaussian Process Covariance Functions".
 #'
+#'  There are several parameters estimated for GPs, the most important of which
+#'  are as follows:
+#'  \tabular{llll}{
+#'  \strong{Parameter} \tab \strong{Notation} \tab \strong{Support} \tab \strong{Meaning} \cr
+#'  \code{lscale} \tab \eqn{\ell} \tab \eqn{\mathbb{R}^+} \tab length-scale of the GP's covariance kernel \cr
+#'  \code{sdgp} \tab \eqn{\sigma} \tab \eqn{\mathbb{R}^+} \tab marginal standard deviation of the GP's covariance kernel \cr
+#'  \code{zgp} \tab \eqn{z} \tab \eqn{\mathbb{R}} \tab latent variable values of the training data \cr
+#'  }
+#'  Assuming an exponentiated quadratic covariance structure, the parameters
+#'  can be broadly interpreted as follows (see also
+#'  \url{https://mc-stan.org/docs/stan-users-guide/gaussian-processes.html#gaussian-process-regression}).
+#'  Note that in the above documentation the parameter \eqn{\sigma} is denoted
+#'  as \eqn{\alpha} instead, and the parameter \eqn{\ell} as \eqn{\rho}.
+#'  The length-scale \eqn{\ell} controls the frequency of the functions
+#'  represented by the GP prior i.e., values of \eqn{\ell \gg 0} lead to
+#'  lower-frequency functions, while values of \eqn{\ell \approx 0} lead to
+#'  higher-frequency functions. In slightly simpler terms, \eqn{\ell} sets
+#'  the distance over which observations in the input space are strongly
+#'  correlated. The marginal standard deviation \eqn{\sigma} controls the
+#'  magnitude of the range of the function represented by the GP i.e., it
+#'  represents how much the values of the function tend to deviate from the
+#'  mean level. Lastly, the parameter \eqn{z} represents latent variable values
+#'  per observation (or unique input point).
+#'
 #' @return An object of class \code{'gp_term'}, which is a list
 #'   of arguments to be interpreted by the formula
 #'   parsing functions of \pkg{brms}.
@@ -107,11 +131,10 @@
 #' @export
 gp <- function(..., by = NA, k = NA, cov = "exp_quad", iso = TRUE,
                gr = TRUE, cmc = TRUE, scale = TRUE, c = 5/4) {
-  cov_choices <- c("exp_quad", "matern52", "matern32", "exponential")
-  cov <- match.arg(cov, choices = cov_choices)
   call <- match.call()
   label <- deparse0(call)
   vars <- as.list(substitute(list(...)))[-1]
+  cov <- validate_gp_cov(cov, k = k)
   by <- deparse0(substitute(by))
   cmc <- as_one_logical(cmc)
   if (is.null(call[["gr"]]) && require_old_default("2.12.8")) {
@@ -126,10 +149,6 @@ gp <- function(..., by = NA, k = NA, cov = "exp_quad", iso = TRUE,
     iso <- TRUE
   }
   if (!isNA(k)) {
-    supported_hsgp_covs <- c("exp_quad", "matern52", "matern32")
-    if (!cov %in% supported_hsgp_covs) {
-      stop2("HSGPs with covariance kernel '", cov, "' are not yet supported.")
-    }
     k <- as.integer(as_one_numeric(k))
     if (k < 1L) {
       stop2("'k' must be positive.")
@@ -322,6 +341,34 @@ spd_gp_exp_quad <- function(x, sdgp = 1, lscale = 1) {
   out
 }
 
+# spectral density function of the exponential kernel
+# vectorized over parameter values
+spd_gp_exponential <- function(x, sdgp = 1, lscale = 1) {
+  NB <- NROW(x)
+  D <- NCOL(x)
+  Dls <- NCOL(lscale)
+  constant = square(sdgp) *
+    (2^D * pi^(D / 2) * gamma((D + 1) / 2)) / sqrt(pi)
+  expo = -(D + 1) / 2
+  lscale2 <- lscale^2
+  out <- matrix(nrow = length(sdgp), ncol = NB)
+  if (Dls == 1L) {
+    # one dimensional or isotropic GP
+    constant <- constant * lscale^D
+    for (m in seq_len(NB)) {
+      out[, m] <- constant * (1 + lscale2 * sum(x[m, ]^2))^expo;
+    }
+  } else {
+    # multi-dimensional non-isotropic GP
+    constant <- constant * matrixStats::rowProds(lscale)
+    for (m in seq_len(NB)) {
+      x2 <- data2draws(x[m, ]^2, dim = dim(lscale))
+      out[, m] <- constant * (1 + rowSums(lscale2 * x2))^expo
+    }
+  }
+  out
+}
+
 # spectral density function of the Matern 3/2 kernel
 # vectorized over parameter values
 spd_gp_matern32 <- function(x, sdgp = 1, lscale = 1) {
@@ -406,6 +453,28 @@ choose_L <- function(x, c) {
   c * range
 }
 
+# validate the 'cov' argument of 'gp' terms
+validate_gp_cov <- function(cov, k = NA) {
+  cov <- as_one_character(cov)
+  if (cov == "matern12") {
+    # matern12 and exponential refer to the same kernel
+    cov <- "exponential"
+  }
+  cov_choices <- c("exp_quad", "matern52", "matern32", "exponential")
+  if (!cov %in% cov_choices) {
+    stop2("'", cov, "' is not a valid GP covariance kernel. Valid kernels are: ",
+          collapse_comma(cov_choices))
+  }
+  if (!isNA(k)) {
+    # currently all kernels support HSGPs but this may change in the future
+    hs_cov_choices <- c("exp_quad", "matern52", "matern32", "exponential")
+    if (!cov %in% hs_cov_choices) {
+      stop2("HSGPs with covariance kernel '", cov, "' are not yet supported.")
+    }
+  }
+  cov
+}
+
 # try to evaluate a GP term and
 # return an informative error message if it fails
 try_nug <- function(expr, nug) {
