@@ -20,6 +20,8 @@
 #'   for classes \code{"b"}. Defaults to \code{NULL}, that is no restriction.
 #' @param ub Upper bound for parameter restriction. Currently only allowed
 #'   for classes \code{"b"}. Defaults to \code{NULL}, that is no restriction.
+#' @param tag Character to append to the \code{lprior} variable in the Stan code.
+#'   Used for selectively checking sensitivity of priors in \code{priorsense}.
 #' @param check Logical; Indicates whether priors
 #'   should be checked for validity (as far as possible).
 #'   Defaults to \code{TRUE}. If \code{FALSE}, \code{prior} is passed
@@ -357,11 +359,19 @@
 #' # useful in particular for categorical or multivariate models
 #' set_prior("normal(0, 2)", dpar = c("muX", "muY", "muZ"))
 #'
+#' # specify tags for different priors for sensitivity analysis using priorsense
+#' # It is then possible to check the sensitivity when changing the priors with
+#' # the same tag while leaving others the same
+#' prior_cov <- prior(normal(0, 10), class = "b", tag = "covariates")
+#' prior_trt <- prior(normal(0, 1), class = "b", coef = "Trt1", tag = "treatment")
+#' stancode(count ~ Trt + zAge + zBase + (1 | patient),
+#'          data = epilepsy, prior = c(prior_cov, prior_trt))
+#'
 #' @export
 set_prior <- function(prior, class = "b", coef = "", group = "",
                       resp = "", dpar = "", nlpar = "",
-                      lb = NA, ub = NA, check = TRUE) {
-  input <- nlist(prior, class, coef, group, resp, dpar, nlpar, lb, ub, check)
+                      lb = NA, ub = NA, tag = "", check = TRUE) {
+  input <- nlist(prior, class, coef, group, resp, dpar, nlpar, lb, ub, tag, check)
   input <- try(as.data.frame(input), silent = TRUE)
   if (is_try_error(input)) {
     stop2("Processing arguments of 'set_prior' has failed:\n", input)
@@ -375,7 +385,7 @@ set_prior <- function(prior, class = "b", coef = "", group = "",
 
 # validate arguments passed to 'set_prior'
 .set_prior <- function(prior, class, coef, group, resp,
-                       dpar, nlpar, lb, ub, check) {
+                       dpar, nlpar, lb, ub, tag, check) {
   prior <- as_one_character(prior)
   class <- as_one_character(class)
   group <- as_one_character(group)
@@ -386,16 +396,17 @@ set_prior <- function(prior, class = "b", coef = "", group = "",
   check <- as_one_logical(check)
   lb <- as_one_character(lb, allow_na = TRUE)
   ub <- as_one_character(ub, allow_na = TRUE)
+  tag <- as_one_character(tag)
   if (dpar == "mu") {
     # distributional parameter 'mu' is currently implicit #1368
     dpar <- ""
   }
   if (!check) {
     # prior will be added to the log-posterior as is
-    class <- coef <- group <- resp <- dpar <- nlpar <- lb <- ub <- ""
+    class <- coef <- group <- resp <- dpar <- nlpar <- lb <- ub <- tag <- ""
   }
   source <- "user"
-  out <- nlist(prior, source, class, coef, group, resp, dpar, nlpar, lb, ub)
+  out <- nlist(prior, source, class, coef, group, resp, dpar, nlpar, lb, ub, tag)
   do_call(brmsprior, out)
 }
 
@@ -542,6 +553,14 @@ default_prior.default <- function(object, data, family = gaussian(), autocor = N
   .default_prior(bframe, ...)
 }
 
+#' @export
+default_prior.brmsfit <- function(object, ...) {
+  object <- restructure(object)
+  bterms <- brmsterms(object$formula)
+  bframe <- brmsframe(bterms, data = object$data)
+  .default_prior(bframe, ...)
+}
+
 # internal work function of 'default_prior'
 # @param internal return priors for internal use?
 # @return a brmsprior object
@@ -558,7 +577,7 @@ default_prior.default <- function(object, data, family = gaussian(), autocor = N
   # explicitly label default priors as such
   prior$source <- "default"
   # apply 'unique' as the same prior may have been included multiple times
-  to_order <- with(prior, order(resp, dpar, nlpar, class, group, coef))
+  to_order <- with(prior, order(resp, dpar, nlpar, class, group, coef, tag))
   prior <- unique(prior[to_order, , drop = FALSE])
   rownames(prior) <- NULL
   class(prior) <- c("brmsprior", "data.frame")
@@ -582,12 +601,6 @@ prior_predictor.mvbrmsframe <- function(x, internal = FALSE, ...) {
   for (i in seq_along(x$terms)) {
     prior <- prior + prior_predictor(x$terms[[i]], internal = internal, ...)
   }
-  for (cl in c("b", "Intercept")) {
-    # deprecated; see warning in 'validate_special_prior'
-    if (any(with(prior, class == cl & coef == ""))) {
-      prior <- prior + brmsprior(class = cl)
-    }
-  }
   if (x$rescor) {
     if (internal) {
       prior <- prior +
@@ -971,7 +984,7 @@ prior_re <- function(bframe, internal = FALSE, ...) {
       }
     }
   }
-  reframe_t <- get_dist_groups(reframe, "student")
+  reframe_t <- subset_reframe_dist(reframe, "student")
   if (isTRUE(nrow(reframe_t) > 0L)) {
     prior <- prior +
       brmsprior("gamma(2, 0.1)", class = "df", group = reframe_t$group, lb = "1")
@@ -1086,7 +1099,7 @@ def_dpar_prior <- function(x, dpar) {
   dpar_class <- dpar_class(dpar, family = x)
   link <- x$dpars[[dpar]]$family$link %||% "identity"
   if (is.function(x$family$prior)) {
-    # experimental use of default priors stored in families #1614
+    # use default priors stored in families #1614
     # TODO: use this feature more generally?
     out <- x$family$prior(dpar_class, link = link)
     if (!is.null(out)) {
@@ -1125,7 +1138,7 @@ def_dpar_prior <- function(x, dpar) {
       sigma = def_scale_prior(x),
       shape = "student_t(3, 0, 2.5)",
       nu = "normal(2.7, 0.8)",
-      phi = "student_t(3, 0, 2.5)",
+      phi =  "student_t(3, 0, 2.5)",
       kappa = "normal(5.0, 0.8)",
       beta = "normal(1.7, 1.3)",
       zi = "logistic(0, 1)",
@@ -1243,6 +1256,11 @@ validate_prior <- function(prior, formula, data, family = gaussian(),
   } else if (!is.brmsprior(prior)) {
     stop2("Argument 'prior' must be a 'brmsprior' object.")
   }
+  if (!"tag" %in% names(prior)) {
+    # the tag column was added in version 2.22.11 (#1724)
+    # manually adding it retains compatibility with old brmsprior objects
+    prior$tag <- ""
+  }
   # when updating existing priors, invalid priors should be allowed
   allow_invalid_prior <- isTRUE(attr(prior, "allow_invalid_prior"))
   # temporarily exclude priors that should not be checked
@@ -1536,7 +1554,9 @@ validate_special_prior.btl <- function(x, prior, allow_autoscale = TRUE, ...) {
           "allowed when using special priors for the whole class."
         )
       }
-      tmp <- attributes(eval2(sub_prior))
+      # the brms function may not be in the search path of formula env
+      sub_prior <- paste0("brms::", sub_prior)
+      tmp <- attributes(eval2(sub_prior, environment(x$formula)))
       tmp$autoscale <- isTRUE(tmp$autoscale) && allow_autoscale
       special[[sc]] <- tmp
     }
@@ -1571,7 +1591,7 @@ get_sample_prior <- function(prior) {
 # create data.frames containing prior information
 brmsprior <- function(prior = "", class = "", coef = "", group = "",
                       resp = "", dpar = "", nlpar = "", lb = "", ub = "",
-                      source = "", ls = list()) {
+                      tag = "", source = "", ls = list()) {
   if (length(ls)) {
     if (is.null(names(ls))) {
       stop("Argument 'ls' must be named.")
@@ -1586,7 +1606,7 @@ brmsprior <- function(prior = "", class = "", coef = "", group = "",
   }
   out <- data.frame(
     prior, class, coef, group,
-    resp, dpar, nlpar, lb, ub, source,
+    resp, dpar, nlpar, lb, ub, tag, source,
     stringsAsFactors = FALSE
   )
   class(out) <- c("brmsprior", "data.frame")
@@ -1600,7 +1620,7 @@ empty_prior <- function() {
   brmsprior(
     prior = char0, source = char0, class = char0,
     coef = char0, group = char0, resp = char0,
-    dpar = char0, nlpar = char0, lb = char0, ub = char0
+    dpar = char0, nlpar = char0, lb = char0, ub = char0, tag = char0
   )
 }
 
@@ -1629,7 +1649,7 @@ prior_bounds <- function(prior) {
 # all columns of brmsprior objects
 all_cols_prior <- function() {
   c("prior", "class", "coef", "group", "resp",
-    "dpar", "nlpar", "lb", "ub", "source")
+    "dpar", "nlpar", "lb", "ub", "tag", "source")
 }
 
 # relevant columns for duplication checks in brmsprior objects
@@ -1788,12 +1808,6 @@ prior_summary.brmsfit <- function(object, all = TRUE, ...) {
   prior
 }
 
-#' @export
-default_prior.brmsfit <- function(object, ...) {
-  # just in case people try to apply default_prior to brmsfit objects
-  prior_summary.brmsfit(object, ...)
-}
-
 #' Checks if argument is a \code{brmsprior} object
 #'
 #' @param x An \R object
@@ -1844,8 +1858,14 @@ prepare_print_prior <- function(x) {
       x$prior[i] <- "(flat)"
     }
   }
+  for (i in which(!nzchar(x$tag))) {
+    base_lprior_tag <- stan_base_prior(x, col = "tag", sel_prior = x[i, ])
+    if (nzchar(base_lprior_tag)) {
+      x$tag[i] <- base_lprior_tag
+    }
+  }
   for (i in which(!nzchar(x$lb) & !nzchar(x$ub))) {
-    base_bounds <- stan_base_prior(x, c("lb", "ub"), sel_prior = x[i, ])
+    base_bounds <- stan_base_prior(x, col = c("lb", "ub"), sel_prior = x[i, ])
     x$lb[i] <- base_bounds[, "lb"]
     x$ub[i] <- base_bounds[, "ub"]
   }
@@ -1921,7 +1941,7 @@ as.brmsprior <- function(x) {
 
   defaults <- c(
     class = "b", coef = "", group = "", resp = "",
-    dpar = "", nlpar = "", lb = NA, ub = NA
+    dpar = "", nlpar = "", lb = NA, ub = NA, tag = ""
   )
   for (v in names(defaults)) {
     if (!v %in% names(x)) {
