@@ -373,6 +373,17 @@ test_that("formula has reasonable ouputs", {
   expect_true(is.brmsformula(formula(fit1)))
 })
 
+test_that("inits has reasonable ouputs", {
+  # rstan backend
+  inits1 <- inits(fit1)
+  expect_type(inits1, "list")
+  expect_length(inits1, nchains(fit1))
+
+  inits2 <- inits(fit2)
+  expect_type(inits2, "list")
+  expect_length(inits2, nchains(fit2))
+})
+
 test_that("hypothesis has reasonable ouputs", {
   hyp <- hypothesis(fit1, c("Age > Trt1", "Trt1:Age = -1"))
   expect_equal(dim(hyp$hypothesis), c(2, 8))
@@ -479,21 +490,47 @@ test_that("loo_R2 has reasonable outputs", {
   expect_equal(dim(R2), c(ndraws(fit1), 1))
 })
 
+test_that("loo_epred has reasonable outputs", {
+  skip_on_cran()
+
+  llp <- SW(loo_epred(fit1))
+  expect_equal(nrow(llp), nobs(fit1))
+
+  newdata <- data.frame(
+    Age = 0, visit = c("a", "b"), Trt = 0,
+    count = 20, patient = 1, Exp = 2, volume = 0
+  )
+  llp <- SW(loo_epred(
+    fit1, newdata = newdata,
+    type = "quantile", probs = c(0.25, 0.75),
+    allow_new_levels = TRUE
+  ))
+  expect_equal(dim(llp), c(nrow(newdata), 2))
+
+  llp <- SW(loo_epred(fit4))
+  expect_equal(nrow(llp), nobs(fit4))
+  expect_equal(dim(llp)[3], 4)
+})
+
 test_that("loo_linpred has reasonable outputs", {
   skip_on_cran()
 
   llp <- SW(loo_linpred(fit1))
-  expect_equal(length(llp), nobs(fit1))
-  expect_error(loo_linpred(fit4), "Method 'loo_linpred'")
+  expect_equal(nrow(llp), nobs(fit1))
+
+  llp <- SW(loo_linpred(fit4))
+  expect_equal(nrow(llp), nobs(fit4))
+  expect_equal(dim(llp)[3], 3)
+
   llp <- SW(loo_linpred(fit2, scale = "response", type = "var"))
-  expect_equal(length(llp), nobs(fit2))
+  expect_equal(nrow(llp), nobs(fit2))
 })
 
 test_that("loo_predict has reasonable outputs", {
   skip_on_cran()
 
   llp <- SW(loo_predict(fit1))
-  expect_equal(length(llp), nobs(fit1))
+  expect_equal(nrow(llp), nobs(fit1))
 
   newdata <- data.frame(
     Age = 0, visit = c("a", "b"), Trt = 0,
@@ -504,9 +541,11 @@ test_that("loo_predict has reasonable outputs", {
     type = "quantile", probs = c(0.25, 0.75),
     allow_new_levels = TRUE
   ))
-  expect_equal(dim(llp), c(2, nrow(newdata)))
+  expect_equal(dim(llp), c(nrow(newdata), 2))
+
   llp <- SW(loo_predict(fit4))
-  expect_equal(length(llp), nobs(fit4))
+  expect_equal(nrow(llp), nobs(fit4))
+  expect_equal(length(dim(llp)), 2)
 })
 
 test_that("loo_predictive_interval has reasonable outputs", {
@@ -642,7 +681,7 @@ test_that("pp_check has reasonable outputs", {
                  group = "visit", newdata = fit1$data[1:10, ])
   expect_ggplot(pp)
 
-  pp <- SW(pp_check(fit1, type = "loo_pit", cores = 1))
+  pp <- SW(pp_check(fit1, type = "loo_pit_qq", cores = 1))
   expect_ggplot(pp)
 
   # ppd plots work
@@ -742,7 +781,7 @@ test_that("predictive_error has reasonable outputs", {
 })
 
 test_that("print has reasonable outputs", {
-  expect_output(SW(print(fit1)), "Group-Level Effects:")
+  expect_output(SW(print(fit1)), "Multilevel Hyperparameters:")
 })
 
 test_that("prior_draws has reasonable outputs", {
@@ -854,7 +893,7 @@ test_that("summary has reasonable outputs", {
                  "u-95% CI", "Rhat", "Bulk_ESS", "Tail_ESS"))
   expect_equal(rownames(summary1$random$visit),
                c("sd(Intercept)", "sd(Trt1)", "cor(Intercept,Trt1)"))
-  expect_output(print(summary1), "Population-Level Effects:")
+  expect_output(print(summary1), "Regression Coefficients:")
   expect_output(print(summary1), "Priors:")
 
   summary5 <- SW(summary(fit5, robust = TRUE))
@@ -877,7 +916,7 @@ test_that("update has reasonable outputs", {
   new_data <- data.frame(
     Age = rnorm(18), visit = rep(c(3, 2, 4), 6),
     Trt = rep(0:1, 9), count = rep(c(5, 17, 28), 6),
-    patient = 1, Exp = 4, volume = 0
+    patient = rep(1:6, each = 3), Exp = 4, volume = 0
   )
   up <- update(fit1, newdata = new_data, save_pars = save_pars(group = FALSE),
                testmode = TRUE)
