@@ -57,10 +57,28 @@ test_that("family functions returns expected results", {
   expect_error(zero_inflated_beta_binomial('sqrt'))
   expect_error(zero_inflated_beta_binomial(link_phi = 'logit'))
   expect_error(zero_inflated_beta_binomial(link_zi = 'log'))
+  expect_equal(hurdle_cumulative()$link, "logit")
+  expect_equal(hurdle_cumulative('probit')$link, "probit")
+  expect_equal(hurdle_cumulative('cauchit')$link, "cauchit")
+  expect_equal(hurdle_cumulative()$link_hu, "logit")
+  expect_equal(hurdle_cumulative()$link_disc, "log")
+  expect_error(hurdle_cumulative(link = "log")$link)
+  expect_error(hurdle_cumulative(link_hu = "probit")$link_hu)
+  expect_error(hurdle_cumulative(link_disc = "logit")$link_disc)
+  expect_equal(xbeta()$link, "logit")
+  expect_equal(xbeta("probit")$link, "probit")
+  expect_equal(xbeta("cloglog")$link, "cloglog")
+  expect_error(xbeta("1/mu"), "xbeta")
+  expect_equal(xbeta(link_phi = "log")$link_phi, "log")
+  expect_equal(xbeta(link_phi = "softplus")$link_phi, "softplus")
+  expect_error(xbeta(link_phi = "sqrt")$link_phi, "sqrt")
+  expect_equal(xbeta(link_kappa = "identity")$link_kappa, "identity")
+  expect_equal(xbeta(link_kappa = "log")$link_kappa, "log")
 })
 
 test_that("print brmsfamily works correctly", {
-  expect_output(print(weibull()), "Family: weibull \nLink function: log")
+    expect_output(print(weibull()), "Family: weibull \nLink function: log")
+    expect_output(print(xbeta()), "Family: xbeta \nLink function: logit")
 })
 
 test_that("mixture returns expected results and errors", {
@@ -84,3 +102,22 @@ test_that("mixture returns expected results and errors", {
   expect_error(mixture(poisson, binomial, order = "x"),
                "Argument 'order' is invalid")
 })
+
+test_that("response interval is defined correctly", {
+    expect_equal(xbeta()$closed, rep(TRUE, 2))
+    expect_equal(xbeta()$ybounds, c(0, 1))
+    expect_equal(xbeta()$type, "real")
+})
+
+test_that("distributional parameters are as expected", {
+    expect_identical(xbeta()$dpars, c("mu", "phi", "kappa"))
+})
+
+test_that("default priors are as expected", {
+    expect_output(print(xbeta()$prior), "gamma\\(0.01, 0.01\\)")
+    expect_output(print(xbeta()$prior), "student\\_t\\(3, 0, 2.5\\)")
+})
+
+test_that("correct STAN code is used", {
+    expect_equal(xbeta()$include, "fun_xbeta.stan")
+})
